==> school_algorithms-1.5.0.tar.gz: school_algorithms-1.5.0/README.md <==
[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]


<details>
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#" >About The Project</a>
    </li>
    <li>
      <a href="#"  >Algorithms</a>
    </li>
     <li>
      <a href="#" >How to Import</a>
    </li>
  </ol>
</details>


# School Algorithms
**school_algorithms** is a **Python** module for secondary school maths and physics equations.

It aims to provide a simple way for secondary school students
to learn and calculate equations that they often use.

### Functions include:
- A function that calculates power from energy and time
- A function that calculates energy from power and time
- A function that calculates time from power and energy
- A function that uses Pythagorean theorem to calculate the hypotenuse of a right-angled triangle
- A function that uses Pythagorean theorem to calculate a leg of a right-angled triangle
- A function that calculates the area of a triangle
- A function that calculates the area of a trapezium
- A function that calculates the area of a circle
- A function that calculates the volume of a right rectangle pyramid
- A function that calculates Elastic Potential energy

#### To import:
```
import school_algorithms
```





[contributors-shield]: https://img.shields.io/github/contributors/Sammygarch/school_algorithms.svg?style=for-the-badge
[contributors-url]: https://github.com/Sammygarch/school_algorithms/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/Sammygarch/school_algorithms.svg?style=for-the-badge
[forks-url]: https://github.com/Sammygarch/school_algorithms/network/members
[stars-shield]: https://img.shields.io/github/stars/Sammygarch/school_algorithms.svg?style=for-the-badge
[stars-url]: https://github.com/Sammygarch/school_algorithms/stargazers
[issues-shield]: https://img.shields.io/github/issues/Sammygarch/school_algorithms.svg?style=for-the-badge
[issues-url]: https://github.com/Sammygarch/school_algorithms/issues
[license-shield]: https://img.shields.io/github/license/Sammygarch/school_algorithms.svg?style=for-the-badge
[license-url]: https://github.com/Sammygarch/school_algorithms/blob/master/LICENSE.txt

==> school_algorithms-1.6.0.tar.gz: school_algorithms-1.6.0/README.md <==
[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Stargazers][stars-shield]][stars-url]
[![Issues][issues-shield]][issues-url]
[![MIT License][license-shield]][license-url]


<details>
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a>About The Project</a>
    </li>
    <li>
      <a>Algorithms</a>
    </li>
     <li>
      <a=>How to Import</a>
    </li>
  </ol>
</details>


# School Algorithms
**school_algorithms** is a **Python** module for secondary school maths and physics equations.
It aims to provide a simple way for secondary school students
to learn and calculate equations that they often use.

### Functions include:
- A function that calculates power from energy and time
- A function that calculates energy from power and time
- A function that calculates time from power and energy
- A function that uses Pythagorean theorem to calculate the hypotenuse of a right-angled triangle
- A function that uses Pythagorean theorem to calculate a leg of a right-angled triangle
- A function that calculates the area of a triangle
- A function that calculates the area of a trapezium
- A function that calculates the area of a circle
- A function that calculates the volume of a right rectangle pyramid
- A function that calculates the circumference of a circle

#### To import:
```
import school_algorithms
```





[contributors-shield]: https://img.shields.io/github/contributors/Sammygarch/school_algorithms.svg?style=for-the-badge
[contributors-url]: https://github.com/Sammygarch/school_algorithms/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/Sammygarch/school_algorithms.svg?style=for-the-badge
[forks-url]: https://github.com/Sammygarch/school_algorithms/network/members
[stars-shield]: https://img.shields.io/github/stars/Sammygarch/school_algorithms.svg?style=for-the-badge
[stars-url]: https://github.com/Sammygarch/school_algorithms/stargazers
[issues-shield]: https://img.shields.io/github/issues/Sammygarch/school_algorithms.svg?style=for-the-badge
[issues-url]: https://github.com/Sammygarch/school_algorithms/issues
[license-shield]: https://img.shields.io/github/license/Sammygarch/school_algorithms.svg?style=for-the-badge
[license-url]: https://github.com/Sammygarch/school_algorithms/blob/master/LICENSE.txt
